@@ -2,9 +2,11 @@ from models import PlanAttr
 from .models import HOST
 from .models import DatabaseInfraDNSList
 
-def add_dns_record(databaseinfra, name, ip, type):
+def add_dns_record(databaseinfra, name, ip, type, database_sufix=None):
         planattr = PlanAttr.objects.get(dbaas_plan=databaseinfra.plan)
-        if planattr.dnsapi_database_sufix:
+        if database_sufix:
+            sufix = '.' + database_sufix
+        elif planattr.dnsapi_database_sufix:
             sufix = '.' + planattr.dnsapi_database_sufix
         else:
             sufix = ''
